# Wenku Downloader 百度文库下载工具

百度文库的下载工具

Usage:

安装

通过 pypi 安装

`pip install wenku`

通过 github 安装

`pip install https://github.com/vinxv/wenku`

下载

`wenku.py https://wenku.baidu.com/view/56b7e84e876fb84ae45c3b3567ec102de3bddf4a.html`

限制：

1. 只能下载可以免费浏览的部分
2. 无法按原格式下载，PPT和 PDF下载为图片格式，Word 下载为 txt 格式
